@@ -36,7 +36,7 @@ strlower(const char *string)
 	c = s;
 
 	for (i = 0; string[i] != '\0' && string[i] != '\r'; i++, s++)
-		*s = tolower(string[i]);
+		*s = tolower((int)string[i]);
 
 	*s = '\0';
 
