@@ -112,14 +112,7 @@ http_verify(const char *header, const char *cip, const int sfd, const int hr)
 		else if (!strncasecmp("HEAD ", line, 5))
 			r = 1;
 	}
-	
-	if (r == 1) {
-		/* access log 1 client ip, date, request string */
-		time(&tnow);
-		t = localtime(&tnow);
-		snprintf(log_1, sizeof(log_1), "%s - - %s \"%s\" ", cip,
-		    sys_date(t), line);
-	} else {
+	if (r == 0) {
 		h = http_head(http_s_501, line, cip, 0);
 		b = http_body(http_s_501, "", h, 0);
 		c[sfd].pfdo++;
@@ -130,8 +123,30 @@ http_verify(const char *header, const char *cip, const int sfd, const int hr)
 		c[sfd].x_sta = 0;
 		free(h);
 		free(b);
+		return (r);
 	}
 
+	/* check for valid uri */
+	if (strstr(header, "/../") != NULL) {
+		h = http_head(http_s_400, line, cip, 0);
+		b = http_body(http_s_400, "", h, 0);
+		c[sfd].pfdo++;
+		c[sfd].pfdn[hr] = 1;
+		c[sfd].pfdh[hr] = strdup(b);
+		c[sfd].x_ful[hr] = 1;
+		c[sfd].x_chk[hr] = 0;
+		c[sfd].x_sta = 0;
+		free(h);
+		free(b);
+		return (0);
+	}
+	
+	/* access log 1 client ip, date, request string */
+	time(&tnow);
+	t = localtime(&tnow);
+	snprintf(log_1, sizeof(log_1), "%s - - %s \"%s\" ", cip,
+	    sys_date(t), line);
+
 	return (r);
 }
 
@@ -1495,6 +1510,13 @@ http_header(const char *header_data, const char *force_status,
 
 		/* cgi found with options */
 		if (r == 1) {
+			if (h->x_idx) {
+				/* for this case the index is wrong, drop it */
+				x = strstr(h->rq_option, config.docindex);
+				if (x != NULL)
+					*x = '\0';
+			}
+
 			strcuti(h->rq_script, h->rq_uri, 0,
 			    (strlen(h->rq_uri) - strlen(h->rq_option)) - 1,
 			    sizeof(h->rq_script));
