@@ -78,6 +78,7 @@ const char *http_s_206		= "206 Partial Content";
 const char *http_s_301		= "301 Moved Permanently";
 const char *http_s_302		= "302 Found";
 const char *http_s_304		= "304 Not Modified";
+const char *http_s_400		= "400 Bad Request";
 const char *http_s_401		= "401 Unauthorized";
 const char *http_s_403		= "403 Forbidden";
 const char *http_s_404		= "404 Not Found";
@@ -104,7 +105,7 @@ const char *http_fn_auw		= "WWW-Authenticate:";
 const char *http_fn_ran		= "Range:";
 const char *http_fn_rac		= "Content-Range:";
 const char *http_fn_aen		= "Accept-Encoding:";
-const char *http_fv_srv		= "nostromo 1.8.6";
+const char *http_fv_srv		= "nostromo 1.8.7";
 const char *http_fv_pro		= "HTTP/1.1";
 const char *http_fv_cgi		= "CGI/1.1";
 const char *http_fv_teg		= "chunked";
@@ -950,7 +951,8 @@ main(int argc, char *argv[])
 		fclose(file);
 		flog(config.logpid, "%d\n", ppid);
 	} else {
-		flogd(config.logserver, "[error] fopen: %s\n", strerror(errno));
+		flogd(config.logserver, "[error] fopen: %s: %s\n",
+		    config.logpid, strerror(errno));
 		exit(1);
 	}
 
